pub struct Cardinality {
pub number: Option<i32>,
pub path: Option<String>,
}Expand description
A Cardinality condition for the Waiter resource. A cardinality condition is met when the number of variables under a specified path prefix reaches a predefined number. For example, if you set a Cardinality condition where the path is set to /foo and the number of paths is set to 2, the following variables would meet the condition in a RuntimeConfig resource: + /foo/variable1 = "value1" + /foo/variable2 = "value2" + /bar/variable3 = "value3" It would not satisfy the same condition with the number set to 3, however, because there is only 2 paths that start with /foo. Cardinality conditions are recursive; all subtrees under the specific path prefix are counted.
This type is not used in any activity, and only used as part of another schema.
Fields
number: Option<i32>The number variables under the path that must exist to meet this condition. Defaults to 1 if not specified.
path: Option<String>The root of the variable subtree to monitor. For example, /foo.